@@ -2,23 +2,19 @@
  * File: libraw_internal_funcs.h
  * Copyright 2008-2009 LibRaw LLC (info@libraw.org)
  * Created: Sat Mar  14, 2008
- *
- * LibRaw internal data structures (not visible outside)
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+
+LibRaw is free software; you can redistribute it and/or modify
+it under the terms of the one of three licenses as you choose:
+
+1. GNU LESSER GENERAL PUBLIC LICENSE version 2.1
+   (See file LICENSE.LGPL provided in LibRaw distribution archive for details).
+
+2. COMMON DEVELOPMENT AND DISTRIBUTION LICENSE (CDDL) Version 1.0
+   (See file LICENSE.CDDL provided in LibRaw distribution archive for details).
+
+3. LibRaw Software License 27032010
+   (See file LICENSE.LibRaw.pdf provided in LibRaw distribution archive for details).
+
  */
 
 #ifndef _LIBRAW_INTERNAL_FUNCS_H
@@ -52,8 +48,12 @@
     ushort*     make_decoder (const uchar *source);
     int         ljpeg_start (struct jhead *jh, int info_only);
     void        ljpeg_end(struct jhead *jh);
-    int         ljpeg_diff (ushort *huff);
-    ushort *    ljpeg_row (int jrow, struct jhead *jh);
+    int         ljpeg_diff (ushort *huff); 
+    int         ljpeg_diff_new (LibRaw_bit_buffer& bits, LibRaw_byte_buffer* buf,ushort *huff);
+    int         ljpeg_diff_pef (LibRaw_bit_buffer& bits, LibRaw_byte_buffer* buf,ushort *huff);
+//    ushort *    ljpeg_row (int jrow, struct jhead *jh);
+    ushort *    ljpeg_row_new (int jrow, struct jhead *jh, LibRaw_bit_buffer& bits,LibRaw_byte_buffer* bytes);
+
     unsigned    ph1_bithuff (int nbits, ushort *huff);
 
 // Canon DSLRs
@@ -62,7 +62,6 @@ void        crw_init_tables (unsigned table, ushort *huff[2]);
     void        canon_compressed_load_raw();
     void        lossless_jpeg_load_raw();
     void        canon_sraw_load_raw();
-void        canon_black(double *, int nblack);
 // Adobe DNG
     void        adobe_copy_pixel (int row, int col, ushort **rp);
     void        adobe_dng_load_raw_lj();
@@ -86,8 +85,9 @@ void        canon_black(double *, int nblack);
     void        fuji_load_raw();
     void        parse_fuji (int offset);
 
-
-
+// RedCine
+    void        parse_redcine();
+    void        redcine_load_raw();
 
 // Rollei
     void        rollei_load_raw();
@@ -140,6 +140,9 @@ void        canon_black(double *, int nblack);
     void        kodak_65000_load_raw();
     void        kodak_rgb_load_raw();
     void        kodak_yrgb_load_raw();
+    void        kodak_ycbcr_load_raw();
+    void        kodak_rgb_load_thumb();
+    void        kodak_ycbcr_load_thumb();
 
 // It's a Sony (and K&M)
     void        sony_decrypt (unsigned *data, int len, int start, int key);
@@ -148,6 +151,20 @@ void        canon_black(double *, int nblack);
     void        sony_arw2_load_raw();
     void        parse_minolta (int base);
 
+// Foveon/Sigma
+    void        foveon_load_camf();
+    void        foveon_load_raw();
+    const char* foveon_camf_param (const char *block, const char *param);
+    void *      foveon_camf_matrix (unsigned dim[3], const char *name);
+    int         foveon_fixed (void *ptr, int size, const char *name);
+    float       foveon_avg (short *pix, int range[2], float cfilt);
+    short *     foveon_make_curve (double max, double mul, double filt);
+    void        foveon_make_curves(short **curvep, float dq[3], float div[3], float filt);
+    int         foveon_apply_curve (short *curve, int i);
+    void        foveon_interpolate();
+    char *      foveon_gets (int offset, char *str, int len);
+    void        parse_foveon();
+
 // CAM/RGB
     void        pseudoinverse (double (*in)[3], double (*out)[3], int size);
     void        cam_xyz_coeff (double cam_xyz[4][3]);
@@ -163,7 +180,8 @@ void        canon_black(double *, int nblack);
     void        linear_table (unsigned len);
     void        parse_kodak_ifd (int base);
     int         parse_tiff_ifd (int base);
-    void        parse_tiff (int base);
+    int         parse_tiff (int base);
+    void        apply_tiff(void);
     void        parse_gps (int base);
     void        romm_coeff (float romm_cam[3][3]);
     void        parse_mos (int offset);
@@ -178,6 +196,46 @@ void        canon_black(double *, int nblack);
 // Tiff writer
     void        tiff_set (ushort *ntag, ushort tag, ushort type, int count, int val);
     void        tiff_head (struct tiff_hdr *th, int full);
+
+// splitted AHD code
+#define TS 256
+    void        ahd_interpolate_green_h_and_v(int top, int left, ushort (*out_rgb)[TS][TS][3]);
+    void ahd_interpolate_r_and_b_in_rgb_and_convert_to_cielab(int top, int left, ushort (*inout_rgb)[TS][3], short (*out_lab)[TS][3], const float (&xyz_cam)[3][4]);
+    void ahd_interpolate_r_and_b_and_convert_to_cielab(int top, int left, ushort (*inout_rgb)[TS][TS][3], short (*out_lab)[TS][TS][3], const float (&xyz_cam)[3][4]);
+    void ahd_interpolate_build_homogeneity_map(int top, int left, short (*lab)[TS][TS][3], char (*out_homogeneity_map)[TS][2]);
+    void ahd_interpolate_combine_homogeneous_pixels(int top, int left, ushort (*rgb)[TS][TS][3], char (*homogeneity_map)[TS][2]);
+
+#undef TS
+
+// LibRaw demosaic packs  functions
+// AMaZe
+    int         LinEqSolve(int,  float*, float*, float*);
+// DCB
+    void        dcb_pp();
+    void        dcb_copy_to_buffer(float (*image2)[3]);
+    void        dcb_restore_from_buffer(float (*image2)[3]);
+    void        dcb_color();
+    void        dcb_color_full();
+    void        dcb_map();
+    void        dcb_correction();
+    void        dcb_correction2();
+    void        dcb_refinement();
+    void        rgb_to_lch(double (*image3)[3]);
+    void        lch_to_rgb(double (*image3)[3]);
+    void        fbdd_correction();
+    void        fbdd_correction2(double (*image3)[3]);
+    void        fbdd_green();
+    void  	dcb_ver(float (*image3)[3]);
+    void 	dcb_hor(float (*image2)[3]);
+    void 	dcb_color2(float (*image2)[3]);
+    void 	dcb_color3(float (*image3)[3]);
+    void 	dcb_decide(float (*image2)[3], float (*image3)[3]);
+    void 	dcb_nyquist();
+// VCD/modified dcraw
+    void        refinement();
+    void        ahd_partial_interpolate(int threshold_value);
+    void        es_median_filter();
+    void        median_filter_new();
 #endif
 
 #endif
